/*
 * Java
 *
 * Copyright 2015-2021 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.app.wadapps.commandserver.comm;

import java.io.IOException;
import java.util.Iterator;
import java.util.logging.Level;
import java.util.logging.Logger;

import com.microej.wadapps.rcommand.CommandConstants;
import com.microej.wadapps.rcommand.WadappsCommands;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.ecom.DeviceManager;
import ej.rcommand.CommandSender;
import ej.rcommand.RemoteCommandManager;
import ej.rcommand.comm.RemoteCommandCommPopulator;
import ej.wadapps.admin.Application;
import ej.wadapps.admin.ApplicationLifecycleListener;
import ej.wadapps.app.BackgroundService;
import ej.wadapps.registry.SharedRegistryFactory;

/**
 *
 */
public class AdminService implements BackgroundService, ApplicationLifecycleListener {
	private final Logger logger;
	private final RemoteCommandCommPopulator adminServer;

	/**
	 *
	 */
	public AdminService() {
		this.logger = Logger.getLogger(AdminService.class.getSimpleName());
		String url = System.getProperty("commandserver.comm.url");
		if (url == null) {
			Iterator<ej.ecom.io.CommPort> ecomPorts = DeviceManager.list(ej.ecom.io.CommPort.class);
			while (ecomPorts.hasNext()) {
				ej.ecom.io.CommPort p = ecomPorts.next();
				url = "comm:" + p.getName() + ";baudrate=115200";
				break;
			}
		}
		this.logger.info("Opening serial admin server on " + url); //$NON-NLS-1$
		this.adminServer = new RemoteCommandCommPopulator(url);
		RemoteCommandManager commandManager = ServiceLoaderFactory.getServiceLoader()
				.getService(RemoteCommandManager.class);
		if (commandManager != null) {
			WadappsCommands.registerCommands(commandManager);
		} else {
			this.logger.warning("No command manager found to initialize"); //$NON-NLS-1$
		}
		SharedRegistryFactory.getSharedRegistry().register(ej.rcommand.connectivity.ConnectivityManager.class,
				this.adminServer);
	}

	@Override
	public void onStart() {
		RemoteCommandManager commandManager = ServiceLoaderFactory.getServiceLoader()
				.getService(RemoteCommandManager.class);
		if (commandManager != null) {
			try {
				this.logger.info("Start the serial admin server"); //$NON-NLS-1$
				this.adminServer.start(commandManager);
			} catch (IOException e) {
				this.logger.log(Level.SEVERE, "Couldn't start the admin server", e); //$NON-NLS-1$
			}
		} else {
			this.logger.warning("No command manager found to start"); //$NON-NLS-1$
		}
	}

	@Override
	public void onStop() {
		RemoteCommandManager commandManager = ServiceLoaderFactory.getServiceLoader()
				.getService(RemoteCommandManager.class);
		if (commandManager != null) {
			this.logger.info("Stop the serial admin server"); //$NON-NLS-1$
			this.adminServer.stop();
		} else {
			this.logger.warning("No command manager found to stop"); //$NON-NLS-1$
		}
	}

	@Override
	public void stateChanged(Application application) {
		RemoteCommandManager commandManager = ServiceLoaderFactory.getServiceLoader()
				.getService(RemoteCommandManager.class);
		for (CommandSender sender : commandManager.getCommandSenders(CommandConstants.STATE_APPLICATION_NOTIFY)) {
			sender.startCommand(CommandConstants.STATE_APPLICATION_NOTIFY);
			sender.sendString(application.getIdentifier());
			sender.sendString(application.getState().name());
			sender.flushCommand();
		}
	}
}
