/*
 * Java
 *
 * Copyright 2018-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package com.microej.profiling.profiler;

/**
 * Profile a system value.
 */
public interface Profiler {
	/**
	 * Gets the current value.
	 *
	 * @return the current value.
	 */
	long getCurrentValue();

	/**
	 * Prints a value with its unit.
	 *
	 * @param value
	 *            the value received from {@link #getCurrentValue()}.
	 * @return a value with its unit.
	 */
	String printValue(long value);

	/**
	 * Gets the profiler's name.
	 *
	 * @return the name.
	 */
	String getName();

	/**
	 * Checks whether a value will appear bigger than another once printed.
	 *
	 * @param v1
	 *            the first value
	 * @param v2
	 *            the second value
	 *
	 * @return <code>true</code> if v1 will look &gt; v2.
	 * @see #printValue(long)
	 */
	boolean isBiggerPrinted(long v1, long v2);
}
