/*
 * Java 1.7
 *
 * Copyright 2017-2018 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.security.command;

import java.io.IOException;
import java.io.InputStream;

import org.eclipse.core.runtime.IProgressMonitor;

/**
 * This interface is implemented by all classes able to decode signed command.
 */
public interface CommandUnwrapper {

	/**
	 * Starts decoding a DER encoded stream, i.e. signedCommand.
	 * <p>
	 * It creates a {@link Command} from the specified stream. Command contents can be accessed from the
	 * {@link Command#getCommandInputStream()} method. The verification of the stream is triggered ONLY when the stream
	 * has been entirely consumed.
	 *
	 * @param wrappedCommandStream
	 *            DER encoded stream.
	 * @param monitor
	 *            the progress monitor to use for reporting progress to the user. It is the caller's responsibility to
	 *            call done() on the given monitor. Accepts <code>null</code>, indicating that no progress should be
	 *            reported and that the operation cannot be cancelled.
	 * @throws IOException
	 *             if an I/O error occurs.
	 * @throws InvalidCommandFormatException
	 *             if an error occurs while unwrapping the command.
	 * @return return the unwrapped @link{Command}.
	 */
	public Command unwrapCommand(InputStream wrappedCommandStream, IProgressMonitor monitor)
			throws IOException, InvalidCommandFormatException;
}
