/*
 * Java
 *
 * Copyright 2015-2017 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.management.util;

import java.util.ArrayList;
import java.util.Collection;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.observable.Observable;
import ej.wadapps.admin.Application;
import ej.wadapps.admin.Application.State;
import ej.wadapps.admin.ApplicationLifecycleListener;
import ej.wadapps.admin.ApplicationsManager;
import ej.wadapps.app.Activity;
import ej.wadapps.management.LaunchersList;

/**
 * Default {@link LaunchersList} implementation.
 */
public class LaunchersListImpl extends Observable implements LaunchersList, ApplicationLifecycleListener {

	private final Collection<Activity> launchers;

	/**
	 * Default constructor.
	 */
	public LaunchersListImpl() {
		this.launchers = new ArrayList<>();
		ServiceLoaderFactory.getServiceLoader().getService(ApplicationsManager.class)
				.addApplicationLifecycleListener(this);
	}

	@Override
	public void add(Activity launcher) {
		synchronized (this.launchers) {
			this.launchers.add(launcher);
		}
		setChanged();
		notifyObservers();
	}

	@Override
	public void remove(Activity launcher) {
		synchronized (this.launchers) {
			this.launchers.remove(launcher);
		}
		setChanged();
		notifyObservers();
	}

	@Override
	public Activity[] getLaunchers() {
		synchronized (this.launchers) {
			return this.launchers.toArray(new Activity[this.launchers.size()]);
		}
	}

	@Override
	public void stateChanged(Application application) {
		if (application.getState() == State.INSTALLED) {
			boolean cleaned;
			synchronized (this.launchers) {
				cleaned = ArrayUtils.cleanup(this.launchers);
			}
			if (cleaned) {
				setChanged();
				notifyObservers();
			}
		}
	}

}
