/*
 * Java
 *
 * Copyright 2015-2017 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.management.util;

import java.util.Collection;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.observable.Observable;
import ej.wadapps.admin.Application;
import ej.wadapps.admin.Application.State;
import ej.wadapps.admin.ApplicationLifecycleListener;
import ej.wadapps.admin.ApplicationsManager;
import ej.wadapps.app.Notification;
import ej.wadapps.management.NotificationsManager;

/**
 * Default {@link NotificationsManager} implementation.
 */
public class NotificationsManagerImpl extends Observable implements NotificationsManager, ApplicationLifecycleListener {

	private final Map<String, Notification> notifications;

	/**
	 * Default constructor.
	 */
	public NotificationsManagerImpl() {
		this.notifications = new HashMap<>();
		ServiceLoaderFactory.getServiceLoader().getService(ApplicationsManager.class)
				.addApplicationLifecycleListener(this);
	}

	@Override
	public void notify(Notification notification) {
		String tag = notification.getTag();
		this.notifications.put(tag, notification);
		setChanged();
		notifyObservers();
	}

	@Override
	public void cancel(String tag) {
		this.notifications.remove(tag);
		setChanged();
		notifyObservers();
	}

	@Override
	public void cancelAll() {
		this.notifications.clear();
		setChanged();
		notifyObservers();
	}

	@Override
	public Notification[] getNotifications() {
		Collection<Notification> values = this.notifications.values();
		return values.toArray(new Notification[values.size()]);
	}

	@Override
	public void stateChanged(Application application) {
		if (application.getState() == State.INSTALLED) {
			ApplicationsManager am = ServiceLoaderFactory.getServiceLoader().getService(ApplicationsManager.class);
			Iterator<String> it = this.notifications.keySet().iterator();
			while (it.hasNext()) {
				if (am.getApplication(this.notifications.get(it.next())) == null) {
					it.remove();
				}
			}
		}
	}
}
