/*
 * Java
 *
 * Copyright 2015-2018 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 *
 */
package com.microej.wadapps.metadata;

import java.io.IOException;

import ej.wadapps.management.ApplicationMetadata;
import ej.wadapps.management.ExtraMetadata;
import ej.wadapps.management.ImageInfo;

/**
 * Backups some application meta-data.
 */
public interface ApplicationMetadataBackup {

	/**
	 * An interface that is implemented by objects that decide if an item should be 
	 * backed up.
	 */
	interface Filter {

		/**
		 * Returns <code>true</code> if the given icon should be backed up.
		 * <code>false</code> otherwise.
		 *
		 * @param icon
		 *            the icon.
		 * @return <code>true</code> if the given icon should be backed up,
		 *         <code>false</code> otherwise.
		 */
		boolean backupIcon(ImageInfo icon);

		/**
		 * Returns <code>true</code> if the given screenshot should be backed
		 * up.<code>false</code> otherwise.
		 *
		 * @param screenshot
		 *            the screenshot.
		 *
		 * @return <code>true</code> if the given screenshot should be backed
		 *         up.<code>false</code> otherwise.
		 */
		boolean backupScreenshot(ImageInfo screenshot);

		/**
		 * Returns <code>true</code> if the given extra metadata should be backed
		 * up.<code>false</code> otherwise.
		 *
		 * @param extraMetadata
		 *            the extra metadata.
		 *
		 * @return <code>true</code> if the given extra metadata should be backed
		 *         up.<code>false</code> otherwise.
		 */
		boolean backupExtraMetadata(ExtraMetadata extraMetadata);
	}

	/**
	 * Serializes the given meta-data.
	 *
	 * @param id
	 *
	 * @param applicationMetadata
	 *            the meta-data to serialize.
	 * @throws IOException
	 *             signals that an I/O exception has occurred.
	 */
	void serialize(String id, ApplicationMetadata applicationMetadata) throws IOException;

	/**
	 * Deserializes the meta-data from the specified input stream.
	 *
	 * @param id
	 *
	 * @return the newly created meta-data.
	 * @throws IOException
	 *             signals that an I/O exception has occurred.
	 */
	ApplicationMetadata deserialize(String id) throws IOException;

	/**
	 * Remove the meta-data of the given id.
	 *
	 * @param id
	 *
	 * @param applicationMetadata
	 *            the meta-data to clear.
	 * @throws IOException
	 *             signals that an I/O exception has occurred.
	 */
	void clear(String id, ApplicationMetadata applicationMetadata) throws IOException;

}
