/*
 * Java
 *
 * Copyright 2015-2021 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.rcommand;

/**
 * Constants used for commands
 */
@SuppressWarnings({ "nls", "javadoc" })
public interface CommandConstants {

	// WARNING: these command descriptions are duplicated in the class
	// com.is2t.microejcompanion.model.CommandConstants in the Android companion
	// application.

	/**
	 * Protocol: none.
	 */
	String DEVICE_INFO = "device_info";

	/**
	 * Protocol: device identifier (string), firmware identifier (string),
	 * firmware version (string), accept icon (boolean), accepted icon width
	 * (int) optional, accepted icon height (int) optional.
	 */
	String DEVICE_INFO_SUCCESS = "device_info_success";

	/**
	 * Protocol: error message (string).
	 */
	String DEVICE_INFO_ERROR = "device_info_error";

	/**
	 * Protocol: application id (string), application name (string), application
	 * version (string), application description (string), with icon (boolean),
	 * icon width (int) optional, icon height (int) optional, icon identifier
	 * (string) optional, icon (stream) optional, application binary (stream).
	 */
	String INSTALL_APPLICATION = "install_application";

	/**
	 * Protocol: none.
	 */
	String INSTALL_APPLICATION_SUCCESS = "install_application_success";

	/**
	 * Protocol: error message (string).
	 */
	String INSTALL_APPLICATION_ERROR = "install_application_error";

	/**
	 * Protocol: application id (string), application name (string), application
	 * version (string), application description (string), icon count n (int), n
	 * times (icon identifier (string), icon width (int), icon height (int),
	 * icon (stream)), application binary (stream).
	 */
	String INSTALL_APPLICATION_PLUS = "install_application_plus";

	/**
	 * Protocol: none.
	 */
	String INSTALL_APPLICATION_PLUS_SUCCESS = "install_application_plus_success";

	/**
	 * Protocol: error message (string).
	 */
	String INSTALL_APPLICATION_PLUS_ERROR = "install_application_plus_error";

	/**
	 * Protocol: application id (string), preferred icon size (int).
	 */
	String GET_APPLICATION_METADATA = "get_application_metadata";

	/**
	 * Protocol: application id (string), application version (string),
	 * application name (string), application description (string), with icon
	 * (boolean), icon identifier (string) optional, icon width (int) optional,
	 * icon height (int) optional, icon (stream) optional.
	 */
	String GET_APPLICATION_METADATA_SUCCESS = "get_application_metadata_success";

	/**
	 * Protocol: error message (string).
	 */
	String GET_APPLICATION_METADATA_ERROR = "get_application_metadata_error";

	/**
	 * Protocol: application id (string).
	 */
	String STATE_APPLICATION = "state_application";

	/**
	 * Protocol: application state (string).
	 */
	String STATE_APPLICATION_SUCCESS = "state_application_success";

	/**
	 * Protocol: error message (string).
	 */
	String STATE_APPLICATION_ERROR = "state_application_error";

	/**
	 * Protocol: application id (string), application state (string).
	 */
	String STATE_APPLICATION_NOTIFY = "state_application_notify";

	/**
	 * Protocol: none.
	 */
	String LIST_APPLICATIONS_PLUS = "list_application_plus";

	int SYSTEM_APP = 0;
	int NOT_SYSTEM_APP = 1;
	int UNKNOWN = 2;

	/**
	 * Protocol: application count n (int), n times (application id (string) ,
	 * application version (string), system application (int see the possible
	 * values above), application state (string)).
	 */
	String LIST_APPLICATIONS_PLUS_SUCCESS = "list_application_plus_success";

	/**
	 * Protocol: error message (string).
	 */
	String LIST_APPLICATIONS_PLUS_ERROR = "list_application_plus_error";

	String PUSH_APPLICATION = "push_application";

	String PUSH_APPLICATION_SUCCESS = "push_application_success";

	String PUSH_APPLICATION_ERROR = "push_application_error";

	String LIST_APPLICATIONS = "list_application";

	String LIST_APPLICATIONS_SUCCESS = "list_application_success";

	String LIST_APPLICATIONS_ERROR = "list_application_error";

	String START_APPLICATION = "start_application";

	String START_APPLICATION_SUCCESS = "start_application_success";

	String START_APPLICATION_ERROR = "start_application_error";

	String STOP_APPLICATION = "stop_application";

	String STOP_APPLICATION_SUCCESS = "stop_application_success";

	String STOP_APPLICATION_ERROR = "stop_application_error";

	String UNINSTALL_APPLICATION = "uninstall_application";

	String UNINSTALL_APPLICATION_SUCCESS = "uninstall_application_success";

	String UNINSTALL_APPLICATION_ERROR = "uninstall_application_error";

	String FACTORY_RESET = "factory_reset";

	/**
	 * Send the status of the connection to the application store. Empty values
	 * for username, user email or url mean that the value is not available.
	 * <p>
	 * Protocol: url (string), username (string), user email (string), is
	 * reachable (boolean), is authenticated (boolean).
	 */
	String APPLICATION_STORE_INFO = "application_store_info";

	/**
	 * Protocol: none.
	 */
	String LIST_COMMANDS = "list_commands";

	/**
	 * Protocol: command count n (int), n times (command (string)).
	 */
	String LIST_COMMANDS_SUCCESS = "list_commands_success";

	/**
	 * Protocol: error message (string).
	 */
	String LIST_COMMANDS_ERROR = "list_commands_error";

	/**
	 * Protocol: property name (string).
	 */
	String GET_SHARED_PROPERTY = "get_shared_property";

	/**
	 * Protocol: hasValue (boolean) (if hasValue property value (string)).
	 */
	String GET_SHARED_PROPERTY_SUCCESS = "get_shared_success";

	/**
	 * Protocol: error message (string).
	 */
	String GET_SHARED_PROPERTY_ERROR = "get_shared_property_error";

	/**
	 * Protocol: property name (string), hasValue (boolean) (if hasValue
	 * property value (string)).
	 */
	String SET_SHARED_PROPERTY = "set_shared_property";

	/**
	 * Protocol: none.
	 */
	String SET_SHARED_PROPERTY_SUCCESS = "set_shared_property_success";

	/**
	 * Protocol: error message (string).
	 */
	String SET_SHARED_PROPERTY_ERROR = "set_shared_property_error";

	/**
	 * Protocol: none.
	 */
	String LIST_ACTIVITIES = "list_activities";

	/**
	 * Protocol: activities count n (int), n times (activity_id (string),
	 * application_id (string)).
	 */
	String LIST_ACTIVITIES_SUCCESS = "list_activities_success";

	/**
	 * Protocol: error message (string).
	 */
	String LIST_ACTIVITIES_ERROR = "list_activities_error";

	/**
	 * Protocol: activity_id (string).
	 */
	String SHOW_ACTIVITY = "show_activity";

	/**
	 * Protocol: none.
	 */
	String SHOW_ACTIVITY_SUCCESS = "show_activity_success";

	/**
	 * Protocol: error message (string).
	 */
	String SHOW_ACTIVITY_ERROR = "show_activity_error";

	/**
	 * Protocol: application_id (string).
	 */
	String SHOW_APPLICATION = "show_application";

	/**
	 * Protocol: none.
	 */
	String SHOW_APPLICATION_SUCCESS = "show_application_success";

	/**
	 * Protocol: error message (string).
	 */
	String SHOW_APPLICATION_ERROR = "show_application_error";

	/**
	 * Protocol: application_id (string).
	 */
	String RUN_APPLICATION = "run_application";

	/**
	 * Protocol: none.
	 */
	String RUN_APPLICATION_SUCCESS = "run_application_success";

	/**
	 * Protocol: error message (string).
	 */
	String RUN_APPLICATION_ERROR = "run_application_error";

	String EXECUTE_COMMAND = "execute_command";
	String EXECUTE_COMMAND_SUCCESS = "execute_command_success";
	String EXECUTE_COMMAND_ERROR = "execute_command_error";
	int EXECUTE_COMMAND_VERSION = 1;

	String SET_METADATA = "set_metadata";
	String SET_METADATA_SUCCESS = "set_metadata_success";
	String SET_METADATA_ERROR = "set_metadata_error";

	/**
	 * Version of the DeviceInfo protocol. Version 1 has:
	 * <ul>
	 * <li>Int: version=1
	 * <li>String: device identifier
	 * <li>String: firmware identifier
	 * <li>String: firmware version
	 * <li>Boolean: acceptIcons
	 * <li>if acceptIcons
	 * <ul>
	 * <li>Int: acceptedIconWidth
	 * <li>Int: acceptedIconHeight
	 * </ul>
	 * <li>Boolean: allowSignedCommands
	 * <li>Boolean: allowUnsignedCommands
	 * </ul>
	 */
	int DEVICE_INFO_VERSION = 1;
}
