/*
 * Java
 *
 * Copyright 2015-2021 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.rcommand;

import java.io.IOException;
import java.io.InputStream;
import java.util.logging.Level;
import java.util.logging.Logger;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.rcommand.CommandReader;
import ej.rcommand.CommandSender;
import ej.wadapps.admin.ApplicationOperationException;
import ej.wadapps.admin.ApplicationsManager;

/**
 * A command allowing to install an application with more parameters.
 */
@SuppressWarnings("nls")
public class ExecuteCommand extends AbstractCommand {
	private final ApplicationsManager applicationsManager;
	private final Logger logger;

	/**
	 * Constructs a signed install application command.
	 */
	public ExecuteCommand() {
		this.applicationsManager = ServiceLoaderFactory.getServiceLoader().getService(ApplicationsManager.class);
		this.logger = Logger.getLogger(ExecuteCommand.class.getSimpleName());
	}

	@Override
	public String getManagedCommand() {
		return CommandConstants.EXECUTE_COMMAND;
	}

	@Override
	protected void commandReceived(CommandReader commandReader, CommandSender commandSender) {
		try {
			int commandVersion = commandReader.readInt();
			if (CommandConstants.EXECUTE_COMMAND_VERSION != commandVersion) {
				throw new IllegalArgumentException("commandVersion (" + commandVersion + ") not supported.");
			}

			try (InputStream applicationBinary = commandReader.readInputStream()) {
				try {
					this.applicationsManager.execute(applicationBinary);
				} catch (ApplicationOperationException | RuntimeException e) {
					try {
						@SuppressWarnings("unused")
						int b;
						while ((b = applicationBinary.read()) != -1) {
							// skip
						}
					} catch (IOException ioex) {
						// silently ignored
					}
					throw e;
				}
				commandSender.startCommand(CommandConstants.EXECUTE_COMMAND_SUCCESS);
				commandSender.flushCommand();
			}
		} catch (ApplicationOperationException | IOException | RuntimeException e) {
			this.logger.log(Level.SEVERE, e.getMessage(), e);
			commandSender.startCommand(CommandConstants.EXECUTE_COMMAND_ERROR);
			if (e.getMessage() != null) {
				commandSender.sendString(e.getMessage());
			} else {
				commandSender.sendString("board internal error");
			}
			commandSender.flushCommand();
		}
	}
}
