/*
 * Java
 *
 * Copyright 2016-2021 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.rcommand;

import java.io.IOException;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.rcommand.CommandReader;
import ej.rcommand.CommandSender;
import ej.wadapps.admin.Application;
import ej.wadapps.admin.ApplicationOperationException;
import ej.wadapps.admin.ApplicationsManager;

/**
 *
 */
public abstract class LifeCycleCommand extends AbstractCommand {

	private final ApplicationsManager am;
	private final String command;
	private final String successResponse;
	private final String errorResponse;

	/**
	 *
	 */
	public LifeCycleCommand(String command, String successResponse, String errorResponse) {
		this.am = ServiceLoaderFactory.getServiceLoader().getService(ApplicationsManager.class);
		this.command = command;
		this.successResponse = successResponse;
		this.errorResponse = errorResponse;
	}

	@Override
	protected String getManagedCommand() {
		return this.command;
	}

	protected abstract void lifeCycleOperation(Application application)
			throws IllegalStateException, SecurityException, ApplicationOperationException;

	@Override
	protected void commandReceived(CommandReader commandReader, CommandSender commandSender) {
		try {
			String applicationId = commandReader.readString();
			for (Application application : this.am.getInstalledApplications()) {
				if (application.getIdentifier().equals(applicationId)) {
					try {
						lifeCycleOperation(application);
						commandSender.startCommand(this.successResponse);
						commandSender.flushCommand();
						return;
					} catch (IllegalStateException e) {
						commandSender.startCommand(this.errorResponse);
						commandSender.sendString(applicationId + " is '" + application.getState() //$NON-NLS-1$
						+ "', operation not supported in this state."); //$NON-NLS-1$
						commandSender.flushCommand();
						return;
					} catch (SecurityException e) {
						commandSender.startCommand(this.errorResponse);
						commandSender.sendString("Security conditions not satisfied."); //$NON-NLS-1$
						commandSender.flushCommand();
						return;
					} catch (Throwable e) {
						commandSender.startCommand(this.errorResponse);
						commandSender.sendString(e.toString());
						commandSender.flushCommand();
						return;
					}
				}
			}
			commandSender.startCommand(this.errorResponse);
			commandSender.sendString(applicationId + " not found"); //$NON-NLS-1$
			commandSender.flushCommand();
		} catch (IOException e) {
			commandSender.startCommand(this.errorResponse);
			commandSender.sendString("I/O error"); //$NON-NLS-1$
			commandSender.flushCommand();
		}
	}
}
