/*
 * Java
 *
 * Copyright 2016-2021 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.rcommand;

import java.util.Collection;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.rcommand.CommandReader;
import ej.rcommand.CommandSender;
import ej.rcommand.RemoteCommandManager;

/**
 * A command allowing to list all the commands registered in the command manager.
 */
public class ListCommandCommand extends AbstractCommand {

	@Override
	protected String getManagedCommand() {
		return CommandConstants.LIST_COMMANDS;
	}

	@Override
	protected void commandReceived(CommandReader commandReader, CommandSender commandSender) {
		RemoteCommandManager commandManager = ServiceLoaderFactory.getServiceLoader()
				.getService(RemoteCommandManager.class);
		Collection<String> registeredCommands = commandManager.getRegisteredCommands();
		commandSender.startCommand(CommandConstants.LIST_COMMANDS_SUCCESS);
		commandSender.sendInt(registeredCommands.size());
		for (String command : registeredCommands) {
			commandSender.sendString(command);
		}
		commandSender.flushCommand();
	}

}
