/*
 * Java
 *
 * Copyright 2016-2021 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.rcommand;

import com.microej.wadapps.kernel.TrustService;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.rcommand.CommandReader;
import ej.rcommand.CommandSender;
import ej.wadapps.admin.Application;
import ej.wadapps.admin.ApplicationsManager;

public class ListCommandPlus extends AbstractCommand {

	private final ApplicationsManager am;

	public ListCommandPlus() {
		this.am = ServiceLoaderFactory.getServiceLoader().getService(ApplicationsManager.class);
	}

	@Override
	protected String getManagedCommand() {
		return CommandConstants.LIST_APPLICATIONS_PLUS;
	}

	@Override
	protected void commandReceived(CommandReader commandReader, CommandSender commandSender) {
		TrustService trustService = ServiceLoaderFactory.getServiceLoader().getService(TrustService.class);
		Application[] applications = this.am.getInstalledApplications();
		commandSender.startCommand(CommandConstants.LIST_APPLICATIONS_PLUS_SUCCESS);
		commandSender.sendInt(applications.length);
		for (Application application : applications) {
			commandSender.sendString(application.getIdentifier());
			commandSender.sendString(application.getVersion());
			int systemApp = trustService == null ? CommandConstants.UNKNOWN
					: trustService.isSystemApp(application) ? CommandConstants.SYSTEM_APP
							: CommandConstants.NOT_SYSTEM_APP;
			commandSender.sendInt(systemApp);
			commandSender.sendString(application.getState().toString());
		}
		commandSender.flushCommand();
	}

}
