/*
 * Java
 *
 * Copyright 2015-2021 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.rcommand;

import ej.rcommand.CommandReader;
import ej.rcommand.CommandSender;
import ej.wadapps.property.SharedProperties;
import ej.wadapps.property.SharedPropertiesFactory;

/**
 * A command allowing to set the value of a shared property.
 */
public class SetSharedPropertyCommand extends AbstractCommand {

	@Override
	public String getManagedCommand() {
		return CommandConstants.SET_SHARED_PROPERTY;
	}

	@Override
	protected void commandReceived(CommandReader commandReader, CommandSender commandSender) {
		try {
			SharedProperties sharedProp = SharedPropertiesFactory.getSharedProperties();
			if (sharedProp == null) {
				commandSender.startCommand(CommandConstants.SET_SHARED_PROPERTY_ERROR);
				commandSender.sendString("No SharedProperties registry"); //$NON-NLS-1$
			} else {
				String propertyName = commandReader.readString();
				boolean hasValue = commandReader.readBoolean();
				String value = hasValue ? commandReader.readString() : null;
				sharedProp.setProperty(propertyName, value);
				commandSender.startCommand(CommandConstants.SET_SHARED_PROPERTY_SUCCESS);
			}
			commandSender.flushCommand();
		} catch (Exception e) {
			commandSender.startCommand(CommandConstants.SET_SHARED_PROPERTY_ERROR);
			commandSender.sendString(e.getMessage());
			commandSender.flushCommand();
		}
	}
}
