/*
 * Java
 *
 * Copyright 2016-2021 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.rcommand;

import com.microej.wadapps.launcher.util.LauncherHelper;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.rcommand.CommandReader;
import ej.rcommand.CommandSender;
import ej.wadapps.admin.Application;
import ej.wadapps.admin.ApplicationsManager;

/**
 * A command allowing to ask the activity scheduler to show an activity.
 */
public class ShowApplicationCommand extends AbstractCommand {

	@Override
	protected String getManagedCommand() {
		return CommandConstants.SHOW_APPLICATION;
	}

	@Override
	protected void commandReceived(CommandReader commandReader, CommandSender commandSender) {
		try {
			String id = commandReader.readString();
			ApplicationsManager admin = ServiceLoaderFactory.getServiceLoader().getService(ApplicationsManager.class);
			if (admin != null) {
				Application[] apps = admin.getInstalledApplications();
				if (apps != null) {
					for (Application app : apps) {
						if (id.equals(app.getIdentifier())) {
							LauncherHelper.show(app);
							commandSender.startCommand(CommandConstants.SHOW_APPLICATION_SUCCESS);
							commandSender.flushCommand();
							return;
						}
					}
				}
			}
			throw new IllegalArgumentException("No such application"); //$NON-NLS-1$
		} catch (Exception e) {
			commandSender.startCommand(CommandConstants.SHOW_APPLICATION_ERROR);
			commandSender.sendString(e.getMessage());
			commandSender.flushCommand();
		}
	}

}
