package com.microej.wadapps.rcommand;
/*
 * Java
 *
 * Copyright 2017 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

import java.io.IOException;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.rcommand.CommandReader;
import ej.rcommand.CommandSender;
import ej.wadapps.admin.Application;
import ej.wadapps.admin.ApplicationsManager;

/**
 * Command allowing to retrieve the running state of an application.
 */
public class StateApplicationCommand extends AbstractCommand {

	@Override
	protected String getManagedCommand() {
		return CommandConstants.STATE_APPLICATION;
	}

	@Override
	protected void commandReceived(CommandReader commandReader, CommandSender commandSender) {
		try {
			String applicationId = commandReader.readString();
			ApplicationsManager applicationsManager = ServiceLoaderFactory.getServiceLoader()
					.getService(ApplicationsManager.class);
			Application[] applications = applicationsManager.getInstalledApplications();

			for (Application application : applications) {
				if (application.getIdentifier().equals(applicationId)) {
					commandSender.startCommand(CommandConstants.STATE_APPLICATION_SUCCESS);
					commandSender.sendString(application.getState().name());
					commandSender.flushCommand();
					return;
				}
			}

			commandSender.startCommand(CommandConstants.STATE_APPLICATION_ERROR);
			commandSender.sendString("No application installed with the given id.");
			commandSender.flushCommand();
		} catch (IOException e) {
			commandSender.startCommand(CommandConstants.STATE_APPLICATION_SUCCESS);
			if (e.getMessage() != null) {
				commandSender.sendString(e.getMessage());
			} else {
				commandSender.sendString("board internal error"); //$NON-NLS-1$
			}
			commandSender.flushCommand();
		}
	}
}
