/*
 * Java
 *
 * Copyright 2018-2021 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.rcommand.util;

import java.io.IOException;
import java.io.InputStream;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.wadapps.storage.Storage;

/**
 *
 */
class OneShotInputStream extends InputStream {

	private final String id;
	private final InputStream in;

	public OneShotInputStream(String id, InputStream in) {
		this.id = id;
		this.in = in;
	}

	@Override
	public int available() throws IOException {
		return this.in.available();
	}

	@Override
	public int read() throws IOException {
		return this.in.read();
	}

	@Override
	public int read(byte[] b, int off, int len) throws IOException {
		return this.in.read(b, off, len);
	}

	@Override
	public long skip(long n) throws IOException {
		return this.in.skip(n);
	}

	@Override
	public boolean markSupported() {
		return this.in.markSupported();
	}

	@Override
	public synchronized void reset() throws IOException {
		this.in.reset();
	}

	@Override
	public synchronized void mark(int readlimit) {
		this.in.mark(readlimit);
	}

	@Override
	public void close() throws IOException {
		this.in.close();
		ServiceLoaderFactory.getServiceLoader().getService(Storage.class).remove(this.id);
	}
}
