/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.util;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import ej.ecom.io.CommConnection;
import ej.ecom.io.CommPort;
import ej.ecom.io.Connector;
import ej.ecom.io.StreamConnection;

public class CommPortConnection implements StreamConnection {
	private static final String DONGLE_CONNECTION_SETTINGS_END = ";bitsperchar=8;stopbits=1;parity=none";
	private boolean connected;
	private OutputStream os;
	private InputStream is;
	private CommConnection comm;
	private final CommPort commPort;
	private final int baudrate;

	public CommPortConnection (CommPort commPort, int baudrate) throws IOException {
		this.commPort = commPort;
		this.baudrate = baudrate;
	}

	@Override
	public DataInputStream openDataInputStream() throws IOException {
		return null;
	}

	@Override
	public void close() throws IOException {
		if (connected) {
			try { is.close(); }
			catch (Exception e1) { e1.printStackTrace(); }
			try { os.close(); }
			catch (Exception e1) { e1.printStackTrace(); }
			try { comm.close(); }
			catch (Exception e1) { e1.printStackTrace(); }
			connected = false;
		}
	}

	@Override
	public DataOutputStream openDataOutputStream() throws IOException {
		return null;
	}

	@Override
	public InputStream openInputStream() throws IOException {
		connect();
		return is;
	}

	@Override
	public OutputStream openOutputStream() throws IOException {
		connect();
		return os;
	}

	private void connect () throws IOException {
		if (!connected) {
			comm = open(commPort);
			is = comm.openInputStream();
			os = comm.openOutputStream();
			connected = true;
		}
	}

	private CommConnection open(CommPort port) throws IOException {
		return (CommConnection)Connector.open("comm:"+port.getName()+";baudrate="+baudrate + DONGLE_CONNECTION_SETTINGS_END);
	}
}
