/*
 * Java
 *
 * Copyright 2014-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.zwave;

interface Window {
	public boolean open () throws InterruptedException;
	public void close ();
	public void error ();
}

public enum Session implements Window {
	NONE(-1),
	RESPONSE(5000),
	CALLBACK(5000),
	RESPONSE_CALLBACK(new Window [] {RESPONSE, CALLBACK}),
	LEARN_READY(200),
	NODE_FOUND(0),
	ADD_NODE(5000),
	INCLUSION(new Window [] {LEARN_READY, NODE_FOUND, ADD_NODE}),
	REMOVE_NODE(5000),
	EXCLUSION(new Window [] {LEARN_READY, NODE_FOUND, REMOVE_NODE});

	private Session(long period) {
		this.period = period;
	}

	private Session(Window [] windows) {
		this.period = -1;
		this.windows = windows;
	}

	@Override
	public synchronized boolean open() throws InterruptedException {
		if (period >= 0) {
			if (!token) {
				error = true;
				wait(period);
			}
			token = false;
			return error;
		} else if (windows != null) {
			for (Window window : windows) {
				error = window.open();
				if (error) {
					return true;
				}
			}
			return false;
		} else {
			return false;
		}
	}

	@Override
	public synchronized void close() {
		error = false;
		token = true;
		notify();
	}

	@Override
	public synchronized void error() {
		error = true;
		token = true;
		notify();
	}

	private boolean token;
	protected boolean error;
	private long period;
	private Window [] windows;

}