/*
 * Java
 *
 * Copyright 2014-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.zwave.frame;

import java.io.IOException;

import ej.basedriver.zwave.Session;
import ej.basedriver.zwave.ZwaveController;
import ej.basedriver.zwave.ZwaveNode;
import ej.basedriver.zwave.ZwaveProtocol;

public class SendData extends RequestFrame {
	/**
	 * @param listener
	 * @param commandID
	 * @param command
	 */
	public SendData(SendDataListener listener, byte commandID, byte command) {
		this(listener, commandID, command, 0);
	}

	/**
	 * @param listener
	 * @param commandID
	 * @param command
	 * @param commandParamterCount
	 */
	public SendData(SendDataListener listener, byte commandID, byte command, int commandParamterCount) {
		super(listener, ZwaveProtocol.FUNC_ID_ZW_SEND_DATA, 6 + commandParamterCount);
		addParameter(listener.getNode().getNodeUid());
		addParameter((byte) (2 + commandParamterCount));
		addParameter(commandID);
		addParameter(command);
	}

	@Override
	public Session getSession() {
		return Session.RESPONSE_CALLBACK;
	}

	@Override
	public void completeContent() {
		content[content.length - 3] = ZwaveProtocol.TRANSMIT_OPTIONS;
		content[content.length - 2] = generateCallback();
		super.completeContent();
	}

	@Override
	public void addParameter(byte parameter) {
		if (parameterIndex >= content.length - 3) {
			throw new IndexOutOfBoundsException();
		}

		content[parameterIndex++] = parameter;
	}

	@Override
	public void handleRequest(ZwaveController controller, DataFrame dataFrame) throws IOException {
		if (content[content.length - 2] == dataFrame.getBytes()[4]) {
			switch (dataFrame.getBytes()[5]) {
			case ZwaveProtocol.TRANSMIT_COMPLETE_OK:
				Session.CALLBACK.close();
				((SendDataListener)listener).callbackComplete(content, 6);
				break;
			case ZwaveProtocol.TRANSMIT_COMPLETE_NO_ACK:
				Session.CALLBACK.error();
				break;
			case ZwaveProtocol.TRANSMIT_COMPLETE_FAIL:
				//TODO retransmission (see Z-Wave 500 Series Appl. Programmers Guide v6.51.03 -- page 76)
				Session.CALLBACK.error();
				break;
			}
		}
	}

	public ZwaveNode getNode () {
		return ((SendDataListener) listener).getNode();
	}
}
