/*
 * Java
 *
 * Copyright 2017-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.data.pubsub.paho;

import java.io.IOException;
import java.io.OutputStream;

import ej.data.DataWriter;
import ej.data.pubsub.MqttContext;
import ej.data.pubsub.MqttListener;

/**
 * Implementation of an {@link MqttContext} that uses Paho.
 */
public class PahoMqttContext implements MqttContext {

	/** The {@link MqttListener} called when data is received. May be null. */
	protected MqttListener listener;

	/** Manager of this connection. */
	private final PahoMqttAgent mqttAgent;

	public PahoMqttContext(PahoMqttAgent mqttAgent){
		this.mqttAgent = mqttAgent;
	}

	@Override
	public void close() throws IOException {
		mqttAgent.cleanupConnection(this);
		this.listener = null;
	}

	@Override
	public DataWriter newPublication(String topic) throws IOException {
		return newPublication(topic, QOS_0, false);
	}

	@Override
	public DataWriter newPublication(String topic, int qos, boolean retain) throws IOException {
		OutputStream os = new MqttPacketOutputStream(topic, mqttAgent.mqttClient, qos, retain);
		DataWriter writer = mqttAgent.agentConfiguration.newDataWriter(os, topic);
		return writer;
	}

	@Override
	public void setListener(MqttListener listener) {
		this.listener = listener;
	}

	@Override
	public void subscribe(String topicFilter) throws IOException {
		subscribe(topicFilter, QOS_0);
	}

	@Override
	public void subscribe(String topicFilter, int qos) throws IOException {
		mqttAgent.subscribe(this, topicFilter, qos);
	}

	@Override
	public void unsubscribe(String topicFilter) throws IOException {
		mqttAgent.unsubscribe(this, topicFilter);
	}

	@Override
	public String getSharedTopicPrefix() {
		return mqttAgent.agentConfiguration.getSharedTopicPrefix();
	}

	@Override
	public String getLocalTopicPrefix() {
		return mqttAgent.agentConfiguration.getLocalTopicPrefix();
	}
}
