/*
 * Java
 *
 * Copyright 2016 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package ej.giml.annotation;

import java.lang.annotation.ElementType;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import javax.annotation.processing.SupportedSourceVersion;
import javax.lang.model.SourceVersion;

/**
 * An annotation to declare a GIML attribute, based on setter method.
 */
@SupportedSourceVersion(SourceVersion.RELEASE_7)
@Target(ElementType.METHOD)
@Retention(RetentionPolicy.SOURCE)
public @interface ElementSetter {
	/**
	 * The GIML container name. Empty name means to use the method name (minus its prefix) ad container name.
	 *
	 * @return the name of this container.
	 */
	String name() default "";

	/**
	 * Defines prefix of the setter, in order to guess described GIML attribute. This prefix is removed from method name
	 * to compute this attribute name. Empty prefix means to look for default prefixes in method name ({@code is},
	 * {@code has} and {@code set}).
	 *
	 * @return the prefix of this attribute.
	 */
	String prefix() default "";
}
