/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.border;

import ej.microui.display.GraphicsContext;
import ej.style.container.Rectangle;

/**
 * Represents and draw a rectangular colored border.
 */
public class SimpleRectangularBorder implements Border {

	private int thickness;

	/**
	 * Creates an empty simple rectangular border (0 pixel thickness).
	 */
	public SimpleRectangularBorder() {
		// thickness = 0; VM DONE
	}

	/**
	 * Creates a simple rectangular border specifying its thickness.
	 *
	 * @param thickness
	 *            the thickness to set.
	 */
	public SimpleRectangularBorder(int thickness) {
		this.thickness = thickness;
	}

	/**
	 * Sets the thickness.
	 *
	 * @param thickness
	 *            the thickness to set.
	 */
	public void setThickness(int thickness) {
		this.thickness = thickness;
	}

	/**
	 * Gets the thickness.
	 *
	 * @return the thickness.
	 */
	public int getThickness() {
		return this.thickness;
	}

	@Override
	public void wrap(Rectangle rectangle) {
		int thickness = this.thickness;
		rectangle.update(-thickness, -thickness, thickness << 1, thickness << 1);
	}

	@Override
	public void unwrap(Rectangle rectangle) {
		int thickness = this.thickness;
		rectangle.update(thickness, thickness, -thickness << 1, -thickness << 1);
	}

	@Override
	public void apply(GraphicsContext g, Rectangle bounds, int color) {
		g.setColor(color);
		int thickness = this.thickness;
		int currentWidth = bounds.getWidth() - 1;
		int currentHeight = bounds.getHeight() - 1;
		for (int i = -1; ++i < thickness;) {
			g.drawRect(i, i, currentWidth, currentHeight);
			currentWidth -= 2;
			currentHeight -= 2;
		}

		g.translate(thickness, thickness);
		unwrap(bounds);
		g.clipRect(0, 0, bounds.getWidth(), bounds.getHeight());
	}

}
