/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.outline;

import ej.microui.display.GraphicsContext;
import ej.style.container.Rectangle;

/**
 * Represents an outline that wraps a rectangle.
 * <p>
 * The outlines implement the CSS box model. An outline is a box that wraps another box. An element is wrapped in a
 * sequence of outlines: the padding, the border then the margin:<br>
 * <img src="../doc-files/boxmodel.png" alt="Outlines model.">
 *
 * @see ej.style.Style#getBorder()
 * @see ej.style.Style#getPadding()
 * @see ej.style.Style#getMargin()
 *
 */
public interface Outline {

	/**
	 * Adds the outline thickness to a rectangle.
	 *
	 * @param rectangle
	 *            the rectangle to wrap.
	 */
	void wrap(Rectangle rectangle);

	/**
	 * Removes the outline thickness from a rectangle.
	 *
	 * @param rectangle
	 *            the rectangle to unwrap.
	 */
	void unwrap(Rectangle rectangle);

	/**
	 * Applies the outline on a graphics context.
	 *
	 * @param g
	 *            the graphics context.
	 * @param rectangle
	 *            the rectangle to unwrap.
	 */
	void apply(GraphicsContext g, Rectangle rectangle);

}
