/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.selector;

import ej.annotation.Nullable;
import ej.style.Element;
import ej.style.Selector;

/**
 * An attribute set selector selects by checking if an attribute is set.
 * <p>
 * Equivalent to <code>[attribute]</code> selector in CSS. Its specificity is (0,0,1,0).
 *
 * @see Element#getAttribute(String)
 * @see SpecificityHelper
 */
public class AttributeSetSelector implements Selector {

	private final String attribute;

	/**
	 * Creates an attribute set selector.
	 *
	 * @param attribute
	 *            the attribute to check.
	 */
	public AttributeSetSelector(String attribute) {
		this.attribute = attribute;
	}

	@Override
	public boolean fit(Element element) {
		return element.getAttribute(this.attribute) != null;
	}

	@Override
	public int getSpecificity() {
		return SpecificityHelper.getSpecificity(0, 0, 1, 0);
	}

	@Override
	public boolean equals(@Nullable Object obj) {
		if (obj instanceof AttributeSetSelector) {
			AttributeSetSelector other = (AttributeSetSelector) obj;
			return this.attribute.equals(other.attribute);
		}
		return false;
	}

	@Override
	public int hashCode() {
		return this.attribute.hashCode();
	}

}
