/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.selector;

import ej.annotation.Nullable;
import ej.style.Element;
import ej.style.Selector;

/**
 * A type selector selects by checking the element type (Java class).
 * <p>
 * Equivalent to <code>element</code> selector in CSS. Its specificity is (0,0,0,1).
 *
 * @see Object#getClass()
 * @see SpecificityHelper
 */
public class TypeSelector implements Selector {

	private final Class<?> type;

	/**
	 * Creates a type selector.
	 *
	 * @param type
	 *            the type to check.
	 */
	public TypeSelector(Class<?> type) {
		this.type = type;
	}

	@Override
	public boolean fit(Element element) {
		return element.getClass() == this.type;
	}

	@Override
	public int getSpecificity() {
		return SpecificityHelper.getSpecificity(0, 0, 0, 1);
	}

	@Override
	public int hashCode() {
		return this.type.hashCode();
	}

	@Override
	public boolean equals(@Nullable Object obj) {
		if (obj instanceof TypeSelector) {
			return ((TypeSelector) obj).type == this.type;
		}
		return false;
	}

}
