package ej.style.selector.combinator;

import ej.style.Element;
import ej.style.Selector;

/**
 * An 'and' combinator selects the elements selected by all its inner selectors.
 */
public class AndCombinator extends Combinator {

	/**
	 * Creates an 'and' combinator.
	 *
	 * @param selector1
	 *            the first child.
	 * @param selector2
	 *            the second child.
	 */
	public AndCombinator(Selector selector1, Selector selector2) {
		super(selector1, selector2);
	}

	/**
	 * Creates an 'and' combinator.
	 *
	 * @param selectors
	 *            the list of selectors.
	 * @throws IllegalArgumentException
	 *             if there is less than two selectors.
	 */
	public AndCombinator(Selector... selectors) {
		super(selectors);
	}

	@Override
	public boolean fit(Element element) {
		for (Selector selector : this.selectors) {
			if (!selector.fit(element)) {
				return false;
			}
		}
		return true;
	}

}
