/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.util.property;

/**
 * A property loader is a map of properties. The keys and their corresponding values are strings.
 */
public interface PropertyLoader {

	/**
	 * Searches for the property with the specified key.
	 *
	 * @param key
	 *            the property key.
	 * @return the string value of the property, or <code>null</code> if the property is not found.
	 */
	String getProperty(String key);

	/**
	 * Searches for the property with the specified key.
	 *
	 * @param key
	 *            the property key.
	 * @param defaultValue
	 *            a default value.
	 * @return the string value of the property, or the default value if the property is not found.
	 */
	String getProperty(String key, String defaultValue);
}
