/*
 * Java
 *
 * Copyright 2014-2015 IS2T. All rights reserved.
 * Use of this source code is governed by a BSD-style license that can be found at http://www.is2t.com/open-source-bsd-license/.
 */
package ej.wadapps.app;


/**
 * Activity is a user interface oriented service.
 */
public interface Activity {

	/**
	 * Gets the activity identifier.
	 *
	 * @return the activity identifier.
	 */
	String getID();

	/**
	 * Creates the activity content.
	 */
	void onCreate();

	/**
	 * Restarts the activity.
	 * <p>
	 * Called after {@link #onStop()} when the activity is being re-displayed on screen and just before {@link #onStart()}.
	 */
	void onRestart();

	/**
	 * Starts the activity.
	 * <p>
	 * It is now visible.
	 */
	void onStart();

	/**
	 * Resumes the activity.
	 * <p>
	 * The user returns to this activity.
	 */
	void onResume();

	/**
	 * Pauses the activity.
	 * <p>
	 * Another activity has come to the foreground.
	 */
	void onPause();

	/**
	 * Stops the activity.
	 * <p>
	 * The activity is no longer visible.
	 */
	void onStop();

	/**
	 * Destroys the activity content.
	 * <p>
	 * All resources must have been released when this method returns.
	 */
	void onDestroy();

}
