/*
 * Java
 *
 * Copyright 2019 IS2T. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break IS2T warranties on the whole library.
 */
package ej.wadapps.application;

import ej.annotation.Nullable;

/**
 * The applications ownership gives information about the ownership of the objects and the thread contexts.
 */
public interface OwnershipHelper {

	/**
	 * Returns the application that owns the given object.
	 * <p>
	 * If the object belongs to the kernel or the application is not found, the method returns {@code null}.
	 * <p>
	 * If the object is a proxy object, the implementation should return the application that owns the referenced
	 * object.
	 *
	 * @param object
	 *            the object.
	 * @return the owner of the object.
	 */
	@Nullable
	Application getOwner(Object object);

	/**
	 * Returns the application that owns the current thread context.
	 * <p>
	 * If the owner is the kernel or the application is not found, the method returns {@code null}.
	 *
	 * @return the current application.
	 */
	@Nullable
	Application getCurrentApplication();

}
