/*
 * Java
 *
 * Copyright 2017 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package ej.wadapps.applicationstore;

/**
 * This interface can be used to retrieve the status and the configuration of a remote application store connector.<p>
 * An instance of this service can be retrieved using service loader or
 * using {@link ApplicationStoreConnections#getConnectionsInfos()}.
 */
public interface ApplicationStoreConnectionInfo {

	/**
	 * Returns the URL of the application store or null if not defined or not accessible.
	 */
	public String getUrl();

	/**
	 * Returns the user name used to connect to the application store or null if not defined or not accessible.
	 */
	public String getUserName();

	/**
	 * Returns the e-mail address of the user connected to the application store or null if not defined or not accessible.
	 */
	public String getUserEmail();

	/**
	 * Returns true if the application store is reachable, false otherwise.
	 */
	public boolean isReachable();

	/**
	 * Returns true if we are authenticated on the application store, false otherwise.
	 */
	public boolean isAuthenticated();

}
