/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.wadapps.management;

import ej.wadapps.app.Activity;

/**
 * Manages the activities lifecycle.
 */
public interface ActivitiesScheduler {

	/**
	 * Sets the current activities launcher.
	 *
	 * @param launcher
	 *            the launcher to set.
	 */
	void setLauncher(Activity launcher);

	/**
	 * Gets the current activities launcher.
	 *
	 * @return the current launcher or <code>null</code> if there is no registered
	 *         launcher.
	 */
	Activity getLauncher();

	/**
	 * Asks to show the current launcher.
	 */
	void showLauncher();

	/**
	 * Asks to show an activity.
	 *
	 * @param activity
	 *            the activity to show an activity from.
	 * @throws NullPointerException
	 *             if the given activity is <code>null</code>.
	 */
	void show(Activity activity) throws NullPointerException;

	/**
	 * Asks to hide an activity.
	 *
	 * @param activity
	 *            the activity to hide.
	 */
	void hide(Activity activity);
}
