/*
 * Java
 *
 * Copyright 2017-2019 IS2T. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break IS2T warranties on the whole library.
 */
package ej.wadapps.monosandbox.property;

import ej.property.PropertyFactory;
import ej.property.loader.CompositePropertyLoader;
import ej.property.loader.FilePropertyLoader;
import ej.property.loader.SystemPropertyLoader;
import ej.service.loader.SystemPropertiesServiceLoader;
import ej.wadapps.application.Application;
import ej.wadapps.application.ApplicationManager;
import ej.wadapps.property.SharedPropertyFactory;

/**
 * Defines the order of the property loading resolution:
 * <ol>
 * <li>the properties defined locally in all apps.</li>
 * <li>the properties registered locally in the instance of property registry.</li>
 * <li>the properties shared in the instance of the shared registry.</li>
 * <li>the properties defined globally in the system properties.</li>
 * </ol>
 */
public class PropertyLoaderMonoSandbox extends CompositePropertyLoader {

	private static final String PROPERTIES_PACKAGE = "/properties/"; //$NON-NLS-1$
	private static final String APPLICATION_PROPERTIES_LIST = ".properties"; //$NON-NLS-1$

	/**
	 * Creates the property loader.
	 */
	public PropertyLoaderMonoSandbox() {
		// Add the service loader for each app.
		SystemPropertiesServiceLoader systemPropertiesServiceLoader = new SystemPropertiesServiceLoader();
		ApplicationManager applicationManager = systemPropertiesServiceLoader.getService(ApplicationManager.class);
		if (applicationManager != null) {
			Application[] installedApplications = applicationManager.getApplications();
			for (Application application : installedApplications) {
				addPropertyLoader(new FilePropertyLoader(
						PROPERTIES_PACKAGE + application.getIdentifier() + APPLICATION_PROPERTIES_LIST));
			}
		}
		addPropertyLoader(PropertyFactory.getPropertyRegistry());
		addPropertyLoader(SharedPropertyFactory.getSharedPropertyRegistry());
		addPropertyLoader(new SystemPropertyLoader());
	}
}
