/*
 * Java
 *
 * Copyright 2019 IS2T. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break IS2T warranties on the whole library.
 */
package ej.wadapps.multisandbox.application;

import ej.annotation.Nullable;
import ej.kf.Kernel;
import ej.kf.Proxy;
import ej.wadapps.application.Application;
import ej.wadapps.application.OwnershipHelper;

/**
 * Implementation of application ownership management over KF.
 */
public class OwnershipHelperKF implements OwnershipHelper {

	private final ApplicationManagerKF applicationManager;

	/**
	 * Creates an ownership helper on KF.
	 *
	 * @param applicationManager
	 *            the applications manager it depends on.
	 */
	public OwnershipHelperKF(ApplicationManagerKF applicationManager) {
		this.applicationManager = applicationManager;
	}

	@Override
	public @Nullable Application getOwner(Object object) {
		Kernel.enter();
		if (object instanceof Proxy<?>) {
			Object obj = ((Proxy<?>) object).getReference();
			if (obj == null) {
				return null;
			}
			object = obj;
		}
		return this.applicationManager.getApplication(Kernel.getOwner(object));
	}

	@Override
	public @Nullable Application getCurrentApplication() {
		return this.applicationManager.getApplication(Kernel.getContextOwner());
	}

}
