/*
 * Java
 *
 * Copyright 2017-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.wadapps.property;

import java.util.HashMap;

import ej.util.property.PropertyLoader;

/**
 * Shared properties are used to share properties between different
 * applications.
 */
public class SharedProperties implements PropertyLoader {
	private final HashMap<String, String> properties = new HashMap<>();

	/**
	 * Creates a new shared properties implementation.
	 */
	public SharedProperties() {
	}

	/**
	 * Sets the property indicated by the specified key.
	 *
	 * @param key
	 *            the key to be placed into this property list.
	 * @param value
	 *            the value corresponding to the key.
	 * @return the previous value of the specified key in this property list, or
	 *         null if it did not have one.
	 */
	public String setProperty(String key, String value) {
		return this.properties.put(key, value);
	}

	@Override
	public String getProperty(String key) {
		return this.properties.get(key);
	}

	@Override
	public String getProperty(String key, String defaultValue) {
		String value = this.getProperty(key);
		return (null != value) ? value : defaultValue;
	}
}
